==> haskell-wai-app-static-3.1.9-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-IQHshVOsfWlA49R48qvFA3
key:                  wai-app-static-3.1.9-IQHshVOsfWlA49R48qvFA3
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  a3a40d1386d27765972559590a93ec76
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-IQHshVOsfWlA49R48qvFA3
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-LjI88QSzeg6Du3gTHOTwfP
    blaze-markup-0.8.3.0-3LhydqQBevSLPC64eL272u bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.3-BpEVtPMHWmHKcIvvSVWrYW
    directory-1.3.7.1 file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filepath-1.4.2.2 http-date-0.0.11-DV6zZkvAMZR45bQm0WVcic
    http-types-0.12.4-7uecRhjtUnyHbQI0kDNqA2
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    optparse-applicative-0.18.1.0-EO4j3VaswTtGiqiAFplF0k
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-4uh2N5X0qi8J6n5m3thcXg
    unordered-containers-0.2.20-1s4f8pAJmee27mGfYrIk99
    wai-3.2.4-LNQZLvP4BwI5qoFlUqY1xm
    wai-extra-3.1.18-7bvLIwAWq5cJ3TQu8PVPer
    warp-3.3.31-5qZQWM2cWaK3toUW3gwoef
    zlib-0.7.0.0-LhSsrPKwRulIEtr0T9BrUB

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.9-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-D8ym7VlHDzLAgE7QnyfdJ7
key:                  wai-app-static-3.1.9-D8ym7VlHDzLAgE7QnyfdJ7
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  3804fc5e52b02d2486be52f6038bf7cc
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-D8ym7VlHDzLAgE7QnyfdJ7
depends:
    base-4.17.2.1 blaze-html-0.9.2.0-KhmoRG3R09V549Pilp7yk8
    blaze-markup-0.8.3.0-7r16xFnCpy97jSGDBGxZET bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.3-KZIm3vPrVCyIrlyoRaXpFj
    directory-1.3.7.1 file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filepath-1.4.2.2 http-date-0.0.11-Kqmg2dgqhYxKtXqUYD055s
    http-types-0.12.4-AnyveerSvWp9fcmJ7pBmmy
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    optparse-applicative-0.18.1.0-1Ar9aW9o69J8KQyhUKGEja
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-7wl3VN2bkjVLyACPiFBxN
    unordered-containers-0.2.20-Jnp6Xrk1NDm4qrPXFyeyaF
    wai-3.2.4-6yvNKQ0UUswJzjrPe1tuVO
    wai-extra-3.1.18-7zPMyPLasumKA48lmOr4vP
    warp-3.3.31-LNQyGmUrjCg6zDV5km21Oc
    zlib-0.7.0.0-CRqYHirV4cyFsC2akuoUKz

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
